@@ -16,19 +16,34 @@ func (c *command) newDescribeCommand() *cobra.Command {
 		Example: examples.BuildExampleString(
 			examples.Example{
 				Text: "Describe Flink UDF artifact.",
-				Code: "confluent flink artifact describe ccp-123456",
+				Code: "confluent flink artifact describe --cloud aws --region us-west-2 cfa-123456",
 			},
 		),
 	}
 
+	pcmd.AddCloudFlag(cmd)
+	pcmd.AddRegionFlagFlink(cmd, c.AuthenticatedCLICommand)
 	pcmd.AddContextFlag(cmd, c.CLICommand)
 	pcmd.AddOutputFlag(cmd)
 
+	cobra.CheckErr(cmd.MarkFlagRequired("cloud"))
+	cobra.CheckErr(cmd.MarkFlagRequired("region"))
+
 	return cmd
 }
 
 func (c *command) describe(cmd *cobra.Command, args []string) error {
-	plugin, err := c.V2Client.DescribeCustomPlugin(args[0])
+	cloud, err := cmd.Flags().GetString("cloud")
+	if err != nil {
+		return err
+	}
+
+	region, err := cmd.Flags().GetString("region")
+	if err != nil {
+		return err
+	}
+
+	plugin, err := c.V2Client.DescribeFlinkArtifact(cloud, region, args[0])
 	if err != nil {
 		return err
 	}
