@@ -8,8 +8,8 @@ import (
 )
 
 type consumerGroupOut struct {
-	ClusterId         string `human:"Cluster" serialized:"cluster_id"`
-	ConsumerGroupId   string `human:"Consumer Group" serialized:"consumer_group_id"`
+	Cluster           string `human:"Cluster" serialized:"cluster"`
+	ConsumerGroup     string `human:"Consumer Group" serialized:"consumer_group"`
 	Coordinator       string `human:"Coordinator" serialized:"coordinator"`
 	IsSimple          bool   `human:"Simple" serialized:"is_simple"`
 	PartitionAssignor string `human:"Partition Assignor" serialized:"partition_assignor"`
