@@ -36,7 +36,7 @@ func (c *linkCommand) delete(cmd *cobra.Command, args []string) error {
 		return err == nil
 	}
 
-	if err := deletion.ValidateAndConfirmDeletion(cmd, args, existenceFunc, resource.ClusterLink, args[0]); err != nil {
+	if err := deletion.ValidateAndConfirm(cmd, args, existenceFunc, resource.ClusterLink); err != nil {
 		return err
 	}
 
