@@ -3,6 +3,7 @@ package login
 import (
 	"context"
 	"fmt"
+	"os"
 	"path/filepath"
 	"regexp"
 	"runtime"
@@ -12,8 +13,8 @@ import (
 
 	ccloudv1 "github.com/confluentinc/ccloud-sdk-go-v1-public"
 
-	"github.com/confluentinc/cli/v3/internal/admin"
 	pauth "github.com/confluentinc/cli/v3/pkg/auth"
+	"github.com/confluentinc/cli/v3/pkg/billing"
 	"github.com/confluentinc/cli/v3/pkg/ccloudv2"
 	pcmd "github.com/confluentinc/cli/v3/pkg/cmd"
 	"github.com/confluentinc/cli/v3/pkg/config"
@@ -21,7 +22,6 @@ import (
 	"github.com/confluentinc/cli/v3/pkg/examples"
 	"github.com/confluentinc/cli/v3/pkg/keychain"
 	"github.com/confluentinc/cli/v3/pkg/log"
-	"github.com/confluentinc/cli/v3/pkg/netrc"
 	"github.com/confluentinc/cli/v3/pkg/output"
 )
 
@@ -30,18 +30,17 @@ type command struct {
 	cfg                      *config.Config
 	ccloudClientFactory      pauth.CCloudClientFactory
 	mdsClientManager         pauth.MDSClientManager
-	netrcHandler             netrc.NetrcHandler
 	loginCredentialsManager  pauth.LoginCredentialsManager
 	loginOrganizationManager pauth.LoginOrganizationManager
 	authTokenHandler         pauth.AuthTokenHandler
 }
 
-func New(cfg *config.Config, prerunner pcmd.PreRunner, ccloudClientFactory pauth.CCloudClientFactory, mdsClientManager pauth.MDSClientManager, netrcHandler netrc.NetrcHandler, loginCredentialsManager pauth.LoginCredentialsManager, loginOrganizationManager pauth.LoginOrganizationManager, authTokenHandler pauth.AuthTokenHandler) *cobra.Command {
+func New(cfg *config.Config, prerunner pcmd.PreRunner, ccloudClientFactory pauth.CCloudClientFactory, mdsClientManager pauth.MDSClientManager, loginCredentialsManager pauth.LoginCredentialsManager, loginOrganizationManager pauth.LoginOrganizationManager, authTokenHandler pauth.AuthTokenHandler) *cobra.Command {
 	cmd := &cobra.Command{
 		Use:   "login",
 		Short: "Log in to Confluent Cloud or Confluent Platform.",
-		Long: fmt.Sprintf("Confluent Cloud:\n\nLog in to Confluent Cloud using your email and password, or using single sign-on (SSO) credentials.\n\nEmail and password login can be accomplished non-interactively using the `%s` and `%s` environment variables.\n\nEmail and password can also be stored locally for non-interactive re-authentication with the `--save` flag.\n\nSSO login can be accomplished headlessly using the `--no-browser` flag, but non-interactive login is not natively supported. Authentication tokens last 8 hours and are automatically refreshed with CLI client usage. If the client is not used for more than 8 hours, you have to log in again.\n\nLog in to a specific Confluent Cloud organization using the `--organization-id` flag, or by setting the environment variable `%s`.\n\n", pauth.ConfluentCloudEmail, pauth.ConfluentCloudPassword, pauth.ConfluentCloudOrganizationId) +
-			fmt.Sprintf("Confluent Platform:\n\nLog in to Confluent Platform with your username and password, the `--url` flag to identify the location of your Metadata Service (MDS), and the `--ca-cert-path` flag to identify your self-signed certificate chain.\n\nLogin can be accomplished non-interactively using the `%s`, `%s`, `%s`, and `%s` environment variables.\n\nIn a non-interactive login, `%s` replaces the `--url` flag, and `%s` replaces the `--ca-cert-path` flag.\n\nEven with the environment variables set, you can force an interactive login using the `--prompt` flag.", pauth.ConfluentPlatformUsername, pauth.ConfluentPlatformPassword, pauth.ConfluentPlatformMDSURL, pauth.ConfluentPlatformCACertPath, pauth.ConfluentPlatformMDSURL, pauth.ConfluentPlatformCACertPath),
+		Long: fmt.Sprintf("Confluent Cloud:\n\nLog in to Confluent Cloud using your email and password, or using single sign-on (SSO) credentials.\n\nEmail and password login can be accomplished non-interactively using the `%s` and `%s` environment variables.\n\nEmail and password can also be stored locally for non-interactive re-authentication with the `--save` flag.\n\nSSO login can be accomplished headlessly using the `--no-browser` flag, but non-interactive login is not natively supported. Authentication tokens last 8 hours and are automatically refreshed with CLI client usage. If the client is not used for more than 8 hours, you have to log in again.\n\nLog in to a specific Confluent Cloud organization using the `--organization` flag, or by setting the environment variable `%s`.\n\n", pauth.ConfluentCloudEmail, pauth.ConfluentCloudPassword, pauth.ConfluentCloudOrganizationId) +
+			fmt.Sprintf("Confluent Platform:\n\nLog in to Confluent Platform with your username and password, the `--url` flag to identify the location of your Metadata Service (MDS), and the `--certificate-authority-path` flag to identify your self-signed certificate chain.\n\nLogin can be accomplished non-interactively using the `%s`, `%s`, `%s`, and `%s` environment variables.\n\nIn a non-interactive login, `%s` replaces the `--url` flag, and `%s` replaces the `--certificate-authority-path` flag.\n\nEven with the environment variables set, you can force an interactive login using the `--prompt` flag.", pauth.ConfluentPlatformUsername, pauth.ConfluentPlatformPassword, pauth.ConfluentPlatformMDSURL, pauth.ConfluentPlatformCertificateAuthorityPath, pauth.ConfluentPlatformMDSURL, pauth.ConfluentPlatformCertificateAuthorityPath),
 		Args: cobra.NoArgs,
 		Example: examples.BuildExampleString(
 			examples.Example{
@@ -50,19 +49,19 @@ func New(cfg *config.Config, prerunner pcmd.PreRunner, ccloudClientFactory pauth
 			},
 			examples.Example{
 				Text: "Log in to a specific organization in Confluent Cloud.",
-				Code: "confluent login --organization-id 00000000-0000-0000-0000-000000000000",
+				Code: "confluent login --organization 00000000-0000-0000-0000-000000000000",
 			},
 			examples.Example{
 				Text: "Log in to Confluent Platform with a MDS URL.",
 				Code: "confluent login --url http://localhost:8090",
 			},
 			examples.Example{
-				Text: "Log in to Confluent Platform with a MDS URL and CA certificate.",
-				Code: "confluent login --url https://localhost:8090 --ca-cert-path certs/my-cert.crt",
+				Text: "Log in to Confluent Platform with a MDS URL and Certification Authority certificate.",
+				Code: "confluent login --url https://localhost:8090 --certificate-authority-path certs/my-cert.crt",
 			},
 			examples.Example{
-				Text: "Log in to Confluent Platform with SSO and ignore any saved credentials.",
-				Code: "CONFLUENT_PLATFORM_SSO=true confluent login --url https://localhost:8090 --ca-cert-path certs/my-cert.crt",
+				Text: "Log in to Confluent Platform with SSO even if `CONFLUENT_PLATFORM_USERNAME` and `CONFLUENT_PLATFORM_PASSWORD` are set.",
+				Code: "CONFLUENT_PLATFORM_SSO=true confluent login --url https://localhost:8090 --certificate-authority-path certs/my-cert.crt",
 			},
 		),
 	}
@@ -72,7 +71,6 @@ func New(cfg *config.Config, prerunner pcmd.PreRunner, ccloudClientFactory pauth
 		cfg:                      cfg,
 		mdsClientManager:         mdsClientManager,
 		ccloudClientFactory:      ccloudClientFactory,
-		netrcHandler:             netrcHandler,
 		loginCredentialsManager:  loginCredentialsManager,
 		loginOrganizationManager: loginOrganizationManager,
 		authTokenHandler:         authTokenHandler,
@@ -81,9 +79,9 @@ func New(cfg *config.Config, prerunner pcmd.PreRunner, ccloudClientFactory pauth
 
 	cmd.Flags().String("url", "", "Metadata Service (MDS) URL, for on-premises deployments.")
 	cmd.Flags().Bool("us-gov", false, "Log in to the Confluent Cloud US Gov environment.")
-	cmd.Flags().String("ca-cert-path", "", "Self-signed certificate chain in PEM format, for on-premises deployments.")
+	cmd.Flags().String("certificate-authority-path", "", "Self-signed certificate chain in PEM format, for on-premises deployments.")
 	cmd.Flags().Bool("no-browser", false, "Do not open a browser window when authenticating using Single Sign-On (SSO).")
-	cmd.Flags().String("organization-id", "", "The Confluent Cloud organization to log in to. If empty, log in to the default organization.")
+	cmd.Flags().String("organization", "", "The Confluent Cloud organization to log in to. If empty, log in to the default organization.")
 	cmd.Flags().Bool("prompt", false, "Bypass non-interactive login and prompt for login credentials.")
 	cmd.Flags().Bool("save", false, "Save username and encrypted password (non-SSO credentials) to the configuration file in your $HOME directory, and to macOS keychain if applicable. You will be logged back in when your token expires, after one hour for Confluent Cloud, or after six hours for Confluent Platform.")
 
@@ -118,19 +116,19 @@ func (c *command) login(cmd *cobra.Command, _ []string) error {
 }
 
 func (c *command) loginCCloud(cmd *cobra.Command, url string) error {
-	organizationId := c.getOrganizationId(cmd)
+	organization := c.getOrganizationId(cmd)
 
 	noBrowser, err := cmd.Flags().GetBool("no-browser")
 	if err != nil {
 		return err
 	}
 
-	credentials, err := c.getCCloudCredentials(cmd, url, organizationId)
+	credentials, err := c.getCCloudCredentials(cmd, url, organization)
 	if err != nil {
 		return err
 	}
 
-	token, refreshToken, err := c.authTokenHandler.GetCCloudTokens(c.ccloudClientFactory, url, credentials, noBrowser, organizationId)
+	token, refreshToken, err := c.authTokenHandler.GetCCloudTokens(c.ccloudClientFactory, url, credentials, noBrowser, organization)
 
 	endOfFreeTrialErr, isEndOfFreeTrialErr := err.(*errors.EndOfFreeTrialError)
 
@@ -200,14 +198,14 @@ func (c *command) printRemainingFreeCredit(client *ccloudv1.Client, currentOrg *
 
 	// only print remaining free credit if there is any unexpired promo code and there is no payment method yet
 	if remainingFreeCredit > 0 {
-		output.ErrPrintf(c.Config.EnableColor, "Free credits: $%.2f USD remaining\n", admin.ConvertToUSD(remainingFreeCredit))
+		output.ErrPrintf(c.Config.EnableColor, "Free credits: $%.2f USD remaining\n", billing.ConvertToUSD(remainingFreeCredit))
 		output.ErrPrintln(c.Config.EnableColor, "You are currently using a free trial version of Confluent Cloud. Add a payment method with `confluent admin payment update` to avoid an interruption in service once your trial ends.")
 	}
 }
 
-// Order of precedence: env vars > config file > netrc file > prompt
+// Order of precedence: environment variables > configuration file / macOS keychain > prompt
 // i.e. if login credentials found in env vars then acquire token using env vars and skip checking for credentials else where
-func (c *command) getCCloudCredentials(cmd *cobra.Command, url, organizationId string) (*pauth.Credentials, error) {
+func (c *command) getCCloudCredentials(cmd *cobra.Command, url, organization string) (*pauth.Credentials, error) {
 	client := c.ccloudClientFactory.AnonHTTPClientFactory(url)
 	c.loginCredentialsManager.SetCloudClient(client)
 
@@ -216,25 +214,12 @@ func (c *command) getCCloudCredentials(cmd *cobra.Command, url, organizationId s
 		return nil, err
 	}
 	if prompt {
-		return pauth.GetLoginCredentials(c.loginCredentialsManager.GetCloudCredentialsFromPrompt(organizationId))
-	}
-
-	filterParams := netrc.NetrcMachineParams{
-		IsCloud: true,
-		URL:     url,
-	}
-	ctx := c.Config.Context()
-	if strings.Contains(ctx.GetNetrcMachineName(), url) {
-		filterParams.Name = ctx.GetNetrcMachineName()
+		return pauth.GetLoginCredentials(c.loginCredentialsManager.GetCloudCredentialsFromPrompt(organization))
 	}
 
 	return pauth.GetLoginCredentials(
-		c.loginCredentialsManager.GetCloudCredentialsFromEnvVar(organizationId),
-		c.loginCredentialsManager.GetSsoCredentialsFromConfig(c.cfg, url),
-		c.loginCredentialsManager.GetCredentialsFromKeychain(true, filterParams.Name, url),
-		c.loginCredentialsManager.GetCredentialsFromConfig(c.cfg, filterParams),
-		c.loginCredentialsManager.GetCredentialsFromNetrc(filterParams),
-		c.loginCredentialsManager.GetCloudCredentialsFromPrompt(organizationId),
+		c.loginCredentialsManager.GetCloudCredentialsFromEnvVar(organization),
+		c.loginCredentialsManager.GetCloudCredentialsFromPrompt(organization),
 	)
 }
 
@@ -244,7 +229,7 @@ func (c *command) loginMDS(cmd *cobra.Command, url string) error {
 		return err
 	}
 
-	caCertPath, isLegacyContext, err := c.getCaCertPath(cmd, credentials.Username, url)
+	caCertPath, err := c.getCaCertPath(cmd)
 	if err != nil {
 		return err
 	}
@@ -274,7 +259,7 @@ func (c *command) loginMDS(cmd *cobra.Command, url string) error {
 		return err
 	}
 
-	if err := pauth.PersistConfluentLoginToConfig(c.Config, credentials, url, token, refreshToken, caCertPath, isLegacyContext, save); err != nil {
+	if err := pauth.PersistConfluentLoginToConfig(c.Config, credentials, url, token, refreshToken, caCertPath, save); err != nil {
 		return err
 	}
 
@@ -288,42 +273,27 @@ func (c *command) loginMDS(cmd *cobra.Command, url string) error {
 	return nil
 }
 
-// Current functionality:
-// empty ca-cert-path is equivalent to not using ca-cert-path flag
-// if users want to login with ca-cert-path they must explicitly use the flag every time they login
-//
-// For legacy users:
-// if ca-cert-path flag is not used, then return caCertPath value stored in config for the login context
-// if user passes empty string for ca-cert-path flag then reset the ca-cert-path value in config for the context
-// (only for legacy contexts is it still possible for the context name without ca-cert-path to have ca-cert-path)
-func (c *command) getCaCertPath(cmd *cobra.Command, username, url string) (string, bool, error) {
-	caCertPath, err := cmd.Flags().GetString("ca-cert-path")
+func (c *command) getCaCertPath(cmd *cobra.Command) (string, error) {
+	certificateAuthorityPath, err := cmd.Flags().GetString("certificate-authority-path")
 	if err != nil {
-		return "", false, err
+		return "", err
 	}
 
-	if caCertPath == "" {
-		caCertPath = pauth.GetEnvWithFallback(pauth.ConfluentPlatformCACertPath, pauth.DeprecatedConfluentPlatformCACertPath)
+	if certificateAuthorityPath == "" {
+		certificateAuthorityPath = os.Getenv(pauth.ConfluentPlatformCertificateAuthorityPath)
 	}
 
-	var isLegacyContext bool
-	if caCertPath == "" {
-		contextName := pauth.GenerateContextName(username, url, "")
-		caCertPath = c.checkLegacyContextCACertPath(cmd, contextName)
-		isLegacyContext = caCertPath != ""
-	}
-
-	if caCertPath != "" {
-		caCertPath, err = filepath.Abs(caCertPath)
+	if certificateAuthorityPath != "" {
+		certificateAuthorityPath, err = filepath.Abs(certificateAuthorityPath)
 		if err != nil {
-			return "", false, err
+			return "", err
 		}
 	}
 
-	return caCertPath, isLegacyContext, nil
+	return certificateAuthorityPath, nil
 }
 
-// Order of precedence: prompt flag > environment variables (SSO > LDAP) > LDAP (keychain > config > netrc) > SSO > LDAP (prompt)
+// Order of precedence: prompt flag > environment variables (SSO > LDAP) > LDAP (keychain > config) > SSO > LDAP (prompt)
 // i.e. if login credentials found in env vars then acquire token using env vars and skip checking for credentials else where
 // SSO and LDAP (basic auth) can be enabled simultaneously
 func (c *command) getConfluentCredentials(cmd *cobra.Command, url string) (*pauth.Credentials, error) {
@@ -335,7 +305,7 @@ func (c *command) getConfluentCredentials(cmd *cobra.Command, url string) (*paut
 		return pauth.GetLoginCredentials(c.loginCredentialsManager.GetOnPremCredentialsFromPrompt())
 	}
 
-	caCertPath, _, err := c.getCaCertPath(cmd, "", "")
+	caCertPath, err := c.getCaCertPath(cmd)
 	if err != nil {
 		return nil, err
 	}
@@ -352,38 +322,13 @@ func (c *command) getConfluentCredentials(cmd *cobra.Command, url string) (*paut
 		)
 	}
 
-	netrcFilterParams := netrc.NetrcMachineParams{
-		IgnoreCert: true,
-		URL:        url,
-	}
-	ctx := c.Config.Context()
-	if strings.Contains(ctx.GetNetrcMachineName(), url) {
-		netrcFilterParams.Name = ctx.GetNetrcMachineName()
-	}
-
 	return pauth.GetLoginCredentials(
 		c.loginCredentialsManager.GetOnPremCredentialsFromEnvVar(),
-		c.loginCredentialsManager.GetCredentialsFromKeychain(false, netrcFilterParams.Name, url),
-		c.loginCredentialsManager.GetCredentialsFromConfig(c.cfg, netrcFilterParams),
-		c.loginCredentialsManager.GetCredentialsFromNetrc(netrcFilterParams),
 		c.loginCredentialsManager.GetOnPremSsoCredentials(url, caCertPath, unsafeTrace),
 		c.loginCredentialsManager.GetOnPremCredentialsFromPrompt(),
 	)
 }
 
-func (c *command) checkLegacyContextCACertPath(cmd *cobra.Command, contextName string) string {
-	changed := cmd.Flags().Changed("ca-cert-path")
-	// if flag used but empty string is passed then user intends to reset the ca-cert-path
-	if changed {
-		return ""
-	}
-	ctx, ok := c.Config.Contexts[contextName]
-	if !ok {
-		return ""
-	}
-	return ctx.Platform.CaCertPath
-}
-
 func (c *command) getURL(cmd *cobra.Command) (string, error) {
 	url, err := cmd.Flags().GetString("url")
 	if err != nil {
@@ -401,7 +346,7 @@ func (c *command) getURL(cmd *cobra.Command) (string, error) {
 		return "https://confluentgov.com", nil
 	}
 
-	if url := pauth.GetEnvWithFallback(pauth.ConfluentPlatformMDSURL, pauth.DeprecatedConfluentPlatformMDSURL); url != "" {
+	if url := os.Getenv(pauth.ConfluentPlatformMDSURL); url != "" {
 		return url, nil
 	}
 
@@ -414,7 +359,7 @@ func (c *command) saveLoginToKeychain(isCloud bool, url string, credentials *pau
 		return nil
 	}
 
-	ctxName := c.Config.Context().GetNetrcMachineName()
+	ctxName := c.Config.Context().GetMachineName()
 	if err := keychain.Write(isCloud, ctxName, url, credentials.Username, credentials.Password); err != nil {
 		return err
 	}
