@@ -30,23 +30,13 @@ func (c *command) list(cmd *cobra.Command, _ []string) error {
 
 	list := output.NewList(cmd)
 	for _, pipeline := range pipelines {
-		if output.GetFormat(cmd) == output.Human {
-			list.Add(&humanOut{
-				Id:          pipeline.GetId(),
-				Name:        pipeline.Spec.GetDisplayName(),
-				Description: pipeline.Spec.GetDescription(),
-				KsqlCluster: pipeline.Spec.KsqlCluster.GetId(),
-				State:       pipeline.Status.GetState(),
-			})
-		} else {
-			list.Add(&serializedOut{
-				Id:          pipeline.GetId(),
-				Name:        pipeline.Spec.GetDisplayName(),
-				Description: pipeline.Spec.GetDescription(),
-				KsqlCluster: pipeline.Spec.KsqlCluster.GetId(),
-				State:       pipeline.Status.GetState(),
-			})
-		}
+		list.Add(&out{
+			Id:          pipeline.GetId(),
+			Name:        pipeline.Spec.GetDisplayName(),
+			Description: pipeline.Spec.GetDescription(),
+			KsqlCluster: pipeline.Spec.KsqlCluster.GetId(),
+			State:       pipeline.Status.GetState(),
+		})
 	}
 	list.Filter([]string{"Id", "Name", "Description", "KsqlCluster", "State"})
 	return list.Print()
