@@ -12,21 +12,20 @@ import (
 
 func (c *command) newKekCreateCommand(cfg *config.Config) *cobra.Command {
 	cmd := &cobra.Command{
-		Use:   "create",
+		Use:   "create <name>",
 		Short: "Create a Key Encryption Key (KEK).",
-		Args:  cobra.NoArgs,
+		Args:  cobra.ExactArgs(1),
 		RunE:  c.kekCreate,
 		Example: examples.BuildExampleString(
 			examples.Example{
 				Text: "Create a KEK with an AWS KMS key:",
-				Code: "confluent schema-registry kek create --name test --kms-type aws-kms --kms-key-id arn:aws:kms:us-west-2:037502941121:key/a1231e22-1n78-4l0d-9d50-9pww5faedb54 --kms-properties KeyUsage=ENCRYPT_DECRYPT,KeyState=Enabled",
+				Code: "confluent schema-registry kek create my-kek --kms-type aws-kms --kms-key arn:aws:kms:us-west-2:037502941121:key/a1231e22-1n78-4l0d-9d50-9pww5faedb54 --kms-properties KeyUsage=ENCRYPT_DECRYPT,KeyState=Enabled",
 			},
 		),
 	}
 
-	cmd.Flags().String("name", "", "Name of the Key Encryption Key (KEK).")
 	pcmd.AddKmsTypeFlag(cmd)
-	cmd.Flags().String("kms-key-id", "", "The key ID of the Key Management Service (KMS).")
+	cmd.Flags().String("kms-key", "", "The key ID of the Key Management Service (KMS).")
 	cmd.Flags().StringSlice("kms-properties", nil, "A comma-separated list of additional properties (key=value) used to access the Key Management Service (KMS).")
 	cmd.Flags().String("doc", "", "An optional user-friendly description for the Key Encryption Key (KEK).")
 	cmd.Flags().Bool("shared", false, "If the DEK Registry has shared access to the Key Management Service (KMS).")
@@ -39,20 +38,16 @@ func (c *command) newKekCreateCommand(cfg *config.Config) *cobra.Command {
 	}
 	pcmd.AddOutputFlag(cmd)
 
-	cobra.CheckErr(cmd.MarkFlagRequired("name"))
 	cobra.CheckErr(cmd.MarkFlagRequired("kms-type"))
-	cobra.CheckErr(cmd.MarkFlagRequired("kms-key-id"))
+	cobra.CheckErr(cmd.MarkFlagRequired("kms-key"))
 
 	return cmd
 }
 
-func (c *command) kekCreate(cmd *cobra.Command, _ []string) error {
-	client, err := c.GetSchemaRegistryClient(cmd)
-	if err != nil {
-		return err
-	}
+func (c *command) kekCreate(cmd *cobra.Command, args []string) error {
+	name := args[0]
 
-	name, err := cmd.Flags().GetString("name")
+	client, err := c.GetSchemaRegistryClient(cmd)
 	if err != nil {
 		return err
 	}
@@ -62,7 +57,7 @@ func (c *command) kekCreate(cmd *cobra.Command, _ []string) error {
 		return err
 	}
 
-	kmsId, err := cmd.Flags().GetString("kms-key-id")
+	kmsKey, err := cmd.Flags().GetString("kms-key")
 	if err != nil {
 		return err
 	}
@@ -85,7 +80,7 @@ func (c *command) kekCreate(cmd *cobra.Command, _ []string) error {
 	createReq := srsdk.CreateKekRequest{
 		Name:     srsdk.PtrString(name),
 		KmsType:  srsdk.PtrString(kmsType),
-		KmsKeyId: srsdk.PtrString(kmsId),
+		KmsKeyId: srsdk.PtrString(kmsKey),
 		KmsProps: &kmsProps,
 		Doc:      srsdk.PtrString(doc),
 		Shared:   srsdk.PtrBool(shared),
