@@ -20,7 +20,7 @@ func (c *command) newSubjectListCommand(cfg *config.Config) *cobra.Command {
 		RunE:  c.subjectList,
 	}
 
-	cmd.Flags().Bool("deleted", false, "Include deleted subjects.")
+	cmd.Flags().Bool("all", false, "Include deleted subjects.")
 	cmd.Flags().String("prefix", ":*:", "Subject prefix.")
 	pcmd.AddContextFlag(cmd, c.CLICommand)
 	if cfg.IsCloudLogin() {
@@ -31,16 +31,6 @@ func (c *command) newSubjectListCommand(cfg *config.Config) *cobra.Command {
 	}
 	pcmd.AddOutputFlag(cmd)
 
-	if cfg.IsCloudLogin() {
-		// Deprecated
-		pcmd.AddApiKeyFlag(cmd, c.AuthenticatedCLICommand)
-		cobra.CheckErr(cmd.Flags().MarkHidden("api-key"))
-
-		// Deprecated
-		pcmd.AddApiSecretFlag(cmd)
-		cobra.CheckErr(cmd.Flags().MarkHidden("api-secret"))
-	}
-
 	return cmd
 }
 
@@ -50,7 +40,7 @@ func (c *command) subjectList(cmd *cobra.Command, _ []string) error {
 		return err
 	}
 
-	deleted, err := cmd.Flags().GetBool("deleted")
+	all, err := cmd.Flags().GetBool("all")
 	if err != nil {
 		return err
 	}
@@ -60,7 +50,7 @@ func (c *command) subjectList(cmd *cobra.Command, _ []string) error {
 		return err
 	}
 
-	subjects, err := client.List(prefix, deleted)
+	subjects, err := client.List(prefix, all)
 	if err != nil {
 		return err
 	}
