@@ -4,6 +4,7 @@ import (
 	"context"
 	"fmt"
 	"net/http"
+	"os"
 	"slices"
 	"strings"
 
@@ -24,7 +25,6 @@ import (
 	"github.com/confluentinc/cli/v3/pkg/jwt"
 	"github.com/confluentinc/cli/v3/pkg/kafka"
 	"github.com/confluentinc/cli/v3/pkg/log"
-	"github.com/confluentinc/cli/v3/pkg/netrc"
 	"github.com/confluentinc/cli/v3/pkg/output"
 	"github.com/confluentinc/cli/v3/pkg/update"
 	"github.com/confluentinc/cli/v3/pkg/utils"
@@ -46,7 +46,6 @@ type PreRunner interface {
 type PreRun struct {
 	Config                  *config.Config
 	UpdateClient            update.Client
-	FlagResolver            FlagResolver
 	Version                 *version.Version
 	CCloudClientFactory     pauth.CCloudClientFactory
 	MDSClientManager        pauth.MDSClientManager
@@ -134,7 +133,7 @@ func isOnPremLoginCmd(command *CLICommand, isTest bool) bool {
 	if command.CommandPath() != "confluent login" {
 		return false
 	}
-	mdsEnvUrl := pauth.GetEnvWithFallback(pauth.ConfluentPlatformMDSURL, pauth.DeprecatedConfluentPlatformMDSURL)
+	mdsEnvUrl := os.Getenv(pauth.ConfluentPlatformMDSURL)
 	url, _ := command.Flags().GetString("url")
 	return (url == "" && mdsEnvUrl != "") || !ccloudv2.IsCCloudURL(url, isTest)
 }
@@ -143,7 +142,7 @@ func isCloudLoginCmd(command *CLICommand, isTest bool) bool {
 	if command.CommandPath() != "confluent login" {
 		return false
 	}
-	mdsEnvUrl := pauth.GetEnvWithFallback(pauth.ConfluentPlatformMDSURL, pauth.DeprecatedConfluentPlatformMDSURL)
+	mdsEnvUrl := os.Getenv(pauth.ConfluentPlatformMDSURL)
 	url, _ := command.Flags().GetString("url")
 	return (url == "" && mdsEnvUrl == "") || ccloudv2.IsCCloudURL(url, isTest)
 }
@@ -185,12 +184,12 @@ func (r *PreRun) Authenticated(command *AuthenticatedCLICommand) func(*cobra.Com
 		setContextErr := r.setAuthenticatedContext(command)
 		if setContextErr != nil {
 			if _, ok := setContextErr.(*errors.NotLoggedInError); ok {
-				var netrcMachineName string
+				var machineName string
 				if ctx := command.Config.Context(); ctx != nil {
-					netrcMachineName = ctx.GetNetrcMachineName()
+					machineName = ctx.GetMachineName()
 				}
 
-				if err := r.ccloudAutoLogin(netrcMachineName); err != nil {
+				if err := r.ccloudAutoLogin(machineName); err != nil {
 					log.CliLogger.Debugf("Auto login failed: %v", err)
 				} else {
 					setContextErr = r.setAuthenticatedContext(command)
@@ -246,7 +245,7 @@ func (r *PreRun) setAuthenticatedContext(cliCommand *AuthenticatedCLICommand) er
 	return nil
 }
 
-func (r *PreRun) ccloudAutoLogin(netrcMachineName string) error {
+func (r *PreRun) ccloudAutoLogin(machineName string) error {
 	manager := pauth.NewLoginOrganizationManagerImpl()
 	organizationId := pauth.GetLoginOrganization(
 		manager.GetLoginOrganizationFromConfigurationFile(r.Config),
@@ -258,7 +257,7 @@ func (r *PreRun) ccloudAutoLogin(netrcMachineName string) error {
 		url = ctxUrl
 	}
 
-	credentials, err := r.getCCloudCredentials(netrcMachineName, url, organizationId)
+	credentials, err := r.getCCloudCredentials(machineName, url, organizationId)
 	if err != nil {
 		return err
 	}
@@ -281,9 +280,9 @@ func (r *PreRun) ccloudAutoLogin(netrcMachineName string) error {
 	return nil
 }
 
-func (r *PreRun) getCCloudCredentials(netrcMachineName, url, organizationId string) (*pauth.Credentials, error) {
-	filterParams := netrc.NetrcMachineParams{
-		Name:    netrcMachineName,
+func (r *PreRun) getCCloudCredentials(machineName, url, organizationId string) (*pauth.Credentials, error) {
+	filterParams := config.MachineParams{
+		Name:    machineName,
 		IsCloud: true,
 		URL:     url,
 	}
@@ -291,7 +290,6 @@ func (r *PreRun) getCCloudCredentials(netrcMachineName, url, organizationId stri
 		r.LoginCredentialsManager.GetCloudCredentialsFromEnvVar(organizationId),
 		r.LoginCredentialsManager.GetCredentialsFromKeychain(true, filterParams.Name, url),
 		r.LoginCredentialsManager.GetPrerunCredentialsFromConfig(r.Config),
-		r.LoginCredentialsManager.GetCredentialsFromNetrc(filterParams),
 		r.LoginCredentialsManager.GetCredentialsFromConfig(r.Config, filterParams),
 	)
 	if err != nil {
@@ -388,12 +386,7 @@ func (r *PreRun) AuthenticatedWithMDS(command *AuthenticatedCLICommand) func(*co
 		setContextErr := r.setAuthenticatedWithMDSContext(command)
 		if setContextErr != nil {
 			if _, ok := setContextErr.(*errors.NotLoggedInError); ok {
-				var netrcMachineName string
-				if ctx := command.Config.Context(); ctx != nil {
-					netrcMachineName = ctx.GetNetrcMachineName()
-				}
-
-				if err := r.confluentAutoLogin(cmd, netrcMachineName); err != nil {
+				if err := r.confluentAutoLogin(cmd); err != nil {
 					log.CliLogger.Debugf("Auto login failed: %v", err)
 				} else {
 					setContextErr = r.setAuthenticatedWithMDSContext(command)
@@ -443,8 +436,8 @@ func (r *PreRun) setAuthenticatedWithMDSContext(cliCommand *AuthenticatedCLIComm
 	return nil
 }
 
-func (r *PreRun) confluentAutoLogin(cmd *cobra.Command, netrcMachineName string) error {
-	token, refreshToken, credentials, err := r.getConfluentTokenAndCredentials(cmd, netrcMachineName)
+func (r *PreRun) confluentAutoLogin(cmd *cobra.Command) error {
+	token, refreshToken, credentials, err := r.getConfluentTokenAndCredentials(cmd)
 	if err != nil {
 		return err
 	}
@@ -452,7 +445,7 @@ func (r *PreRun) confluentAutoLogin(cmd *cobra.Command, netrcMachineName string)
 		log.CliLogger.Debug("Non-interactive login failed: no credentials")
 		return nil
 	}
-	if err := pauth.PersistConfluentLoginToConfig(r.Config, credentials, credentials.PrerunLoginURL, token, refreshToken, credentials.PrerunLoginCaCertPath, false, false); err != nil {
+	if err := pauth.PersistConfluentLoginToConfig(r.Config, credentials, credentials.PrerunLoginURL, token, refreshToken, credentials.PrerunLoginCaCertPath, false); err != nil {
 		return err
 	}
 	log.CliLogger.Debug(autoLoginMsg)
@@ -460,20 +453,14 @@ func (r *PreRun) confluentAutoLogin(cmd *cobra.Command, netrcMachineName string)
 	return nil
 }
 
-func (r *PreRun) getConfluentTokenAndCredentials(cmd *cobra.Command, netrcMachineName string) (string, string, *pauth.Credentials, error) {
+func (r *PreRun) getConfluentTokenAndCredentials(cmd *cobra.Command) (string, string, *pauth.Credentials, error) {
 	if pauth.IsOnPremSSOEnv() {
 		// Skip auto-login when CONFLUENT_PLATFORM_SSO=true
 		return "", "", nil, nil
 	}
 
-	filterParams := netrc.NetrcMachineParams{
-		Name:    netrcMachineName,
-		IsCloud: false,
-	}
-
 	credentials, err := pauth.GetLoginCredentials(
 		r.LoginCredentialsManager.GetOnPremPrerunCredentialsFromEnvVar(),
-		r.LoginCredentialsManager.GetOnPremPrerunCredentialsFromNetrc(filterParams),
 	)
 	if err != nil {
 		return "", "", nil, err
@@ -515,10 +502,10 @@ func (r *PreRun) createMDSClient(ctx *config.Context, ver *version.Version, unsa
 	}
 	caCertPath := ctx.Platform.CaCertPath
 	// Try to load certs. On failure, warn, but don't error out because this may be an auth command, so there may
-	// be a --ca-cert-path flag on the cmd line that'll fix whatever issue there is with the cert file in the config
+	// be a --certificate-authority-path flag on the cmd line that'll fix whatever issue there is with the cert file in the config
 	client, err := utils.SelfSignedCertClientFromPath(caCertPath)
 	if err != nil {
-		log.CliLogger.Warnf("Unable to load certificate from %s. %s. Resulting SSL errors will be fixed by logging in with the --ca-cert-path flag.", caCertPath, err.Error())
+		log.CliLogger.Warnf("Unable to load certificate from %s. %s. Resulting SSL errors will be fixed by logging in with the --certificate-authority-path flag.", caCertPath, err.Error())
 	} else {
 		mdsConfig.HTTPClient = client
 	}
@@ -599,7 +586,7 @@ type onPremKafkaRestFlagValues struct {
 
 func resolveOnPremKafkaRestFlags(cmd *cobra.Command) (*onPremKafkaRestFlagValues, error) {
 	url, _ := cmd.Flags().GetString("url")
-	caCertPath, _ := cmd.Flags().GetString("ca-cert-path")
+	certificateAAuthorityPath, _ := cmd.Flags().GetString("certificate-authority-path")
 	clientCertPath, _ := cmd.Flags().GetString("client-cert-path")
 	clientKeyPath, _ := cmd.Flags().GetString("client-key-path")
 	noAuthentication, _ := cmd.Flags().GetBool("no-authentication")
@@ -611,7 +598,7 @@ func resolveOnPremKafkaRestFlags(cmd *cobra.Command) (*onPremKafkaRestFlagValues
 
 	values := &onPremKafkaRestFlagValues{
 		url:            url,
-		caCertPath:     caCertPath,
+		caCertPath:     certificateAAuthorityPath,
 		clientCertPath: clientCertPath,
 		clientKeyPath:  clientKeyPath,
 		noAuth:         noAuthentication,
@@ -623,7 +610,7 @@ func resolveOnPremKafkaRestFlags(cmd *cobra.Command) (*onPremKafkaRestFlagValues
 
 func createOnPremKafkaRestClient(ctx *config.Context, caCertPath, clientCertPath, clientKeyPath string, logger *log.Logger) (*http.Client, error) {
 	if caCertPath == "" {
-		caCertPath = pauth.GetEnvWithFallback(pauth.ConfluentPlatformCACertPath, pauth.DeprecatedConfluentPlatformCACertPath)
+		caCertPath = os.Getenv(pauth.ConfluentPlatformCertificateAuthorityPath)
 		logger.Debugf("Found CA cert path: %s", caCertPath)
 	}
 	// use cert path flag or env var if it was passed
@@ -680,9 +667,9 @@ func (r *PreRun) updateToken(tokenErr error, ctx *config.Context, unsafeTrace bo
 }
 
 func (r *PreRun) getUpdatedAuthToken(ctx *config.Context, unsafeTrace bool) (string, string, error) {
-	filterParams := netrc.NetrcMachineParams{
+	filterParams := config.MachineParams{
 		IsCloud: r.Config.IsCloudLogin(),
-		Name:    ctx.GetNetrcMachineName(),
+		Name:    ctx.GetMachineName(),
 	}
 
 	if r.Config.IsCloudLogin() {
@@ -696,7 +683,6 @@ func (r *PreRun) getUpdatedAuthToken(ctx *config.Context, unsafeTrace bool) (str
 			r.LoginCredentialsManager.GetCloudCredentialsFromEnvVar(organizationId),
 			r.LoginCredentialsManager.GetCredentialsFromKeychain(true, ctx.Name, ctx.GetPlatformServer()),
 			r.LoginCredentialsManager.GetPrerunCredentialsFromConfig(r.Config),
-			r.LoginCredentialsManager.GetCredentialsFromNetrc(filterParams),
 			r.LoginCredentialsManager.GetCredentialsFromConfig(r.Config, filterParams),
 		)
 		if err != nil {
@@ -708,7 +694,7 @@ func (r *PreRun) getUpdatedAuthToken(ctx *config.Context, unsafeTrace bool) (str
 		credentials, err := pauth.GetLoginCredentials(
 			r.LoginCredentialsManager.GetOnPremCredentialsFromEnvVar(),
 			r.LoginCredentialsManager.GetCredentialsFromKeychain(false, ctx.Name, ctx.GetPlatformServer()),
-			r.LoginCredentialsManager.GetCredentialsFromNetrc(filterParams),
+			r.LoginCredentialsManager.GetPrerunCredentialsFromConfig(r.Config),
 			r.LoginCredentialsManager.GetCredentialsFromConfig(r.Config, filterParams),
 			r.LoginCredentialsManager.GetOnPremSsoCredentialsFromConfig(r.Config, unsafeTrace),
 		)
@@ -796,10 +782,10 @@ func (r *PreRun) createMDSv2Client(ctx *config.Context, ver *version.Version, un
 	}
 	caCertPath := ctx.Platform.CaCertPath
 	// Try to load certs. On failure, warn, but don't error out because this may be an auth command, so there may
-	// be a --ca-cert-path flag on the cmd line that'll fix whatever issue there is with the cert file in the config
+	// be a --certificate-authority-path flag on the cmd line that'll fix whatever issue there is with the cert file in the config
 	client, err := utils.SelfSignedCertClientFromPath(caCertPath)
 	if err != nil {
-		log.CliLogger.Warnf("Unable to load certificate from %s. %s. Resulting SSL errors will be fixed by logging in with the --ca-cert-path flag.", caCertPath, err.Error())
+		log.CliLogger.Warnf("Unable to load certificate from %s. %s. Resulting SSL errors will be fixed by logging in with the --certificate-authority-path flag.", caCertPath, err.Error())
 	} else {
 		mdsv2Config.HTTPClient = client
 	}
