@@ -4,7 +4,6 @@ import (
 	"bytes"
 	"context"
 	"fmt"
-	"os"
 	"testing"
 
 	"github.com/spf13/cobra"
@@ -21,11 +20,9 @@ import (
 	"github.com/confluentinc/cli/v3/pkg/config"
 	"github.com/confluentinc/cli/v3/pkg/errors"
 	"github.com/confluentinc/cli/v3/pkg/featureflags"
-	"github.com/confluentinc/cli/v3/pkg/form"
 	"github.com/confluentinc/cli/v3/pkg/jwt"
 	"github.com/confluentinc/cli/v3/pkg/log"
 	pmock "github.com/confluentinc/cli/v3/pkg/mock"
-	"github.com/confluentinc/cli/v3/pkg/netrc"
 	"github.com/confluentinc/cli/v3/pkg/update/mock"
 )
 
@@ -60,11 +57,6 @@ var (
 				return nil, nil
 			}
 		},
-		GetCredentialsFromNetrcFunc: func(_ netrc.NetrcMachineParams) func() (*pauth.Credentials, error) {
-			return func() (*pauth.Credentials, error) {
-				return nil, nil
-			}
-		},
 		GetCloudCredentialsFromPromptFunc: func(_ string) func() (*pauth.Credentials, error) {
 			return func() (*pauth.Credentials, error) {
 				return nil, nil
@@ -75,7 +67,7 @@ var (
 				return nil, nil
 			}
 		},
-		GetCredentialsFromConfigFunc: func(_ *config.Config, _ netrc.NetrcMachineParams) func() (*pauth.Credentials, error) {
+		GetCredentialsFromConfigFunc: func(_ *config.Config, _ config.MachineParams) func() (*pauth.Credentials, error) {
 			return func() (*pauth.Credentials, error) {
 				return nil, nil
 			}
@@ -100,10 +92,6 @@ func getPreRunBase() *pcmd.PreRun {
 				return "", "", nil
 			},
 		},
-		FlagResolver: &pcmd.FlagResolverImpl{
-			Prompt: &form.RealPrompt{},
-			Out:    os.Stdout,
-		},
 		CCloudClientFactory: &climock.CCloudClientFactory{
 			JwtHTTPClientFactoryFunc: func(ctx context.Context, jwt, baseURL string) *ccloudv1.Client {
 				return &ccloudv1.Client{}
@@ -232,17 +220,12 @@ func TestUpdateToken(t *testing.T) {
 						return nil, nil
 					}
 				},
-				GetCredentialsFromNetrcFunc: func(_ netrc.NetrcMachineParams) func() (*pauth.Credentials, error) {
-					return func() (*pauth.Credentials, error) {
-						return &pauth.Credentials{Username: "username", Password: "password"}, nil
-					}
-				},
 				GetCredentialsFromKeychainFunc: func(_ bool, _, _ string) func() (*pauth.Credentials, error) {
 					return func() (*pauth.Credentials, error) {
 						return nil, nil
 					}
 				},
-				GetCredentialsFromConfigFunc: func(_ *config.Config, _ netrc.NetrcMachineParams) func() (*pauth.Credentials, error) {
+				GetCredentialsFromConfigFunc: func(_ *config.Config, _ config.MachineParams) func() (*pauth.Credentials, error) {
 					return func() (*pauth.Credentials, error) {
 						return &pauth.Credentials{Username: "username", Password: "password"}, nil
 					}
@@ -262,11 +245,6 @@ func TestUpdateToken(t *testing.T) {
 						return nil, nil
 					}
 				},
-				GetOnPremPrerunCredentialsFromNetrcFunc: func(_ netrc.NetrcMachineParams) func() (*pauth.Credentials, error) {
-					return func() (*pauth.Credentials, error) {
-						return nil, nil
-					}
-				},
 				GetOnPremCredentialsFromEnvVarFunc: func() func() (*pauth.Credentials, error) {
 					return func() (*pauth.Credentials, error) {
 						return nil, nil
@@ -313,12 +291,10 @@ func TestPrerun_AutoLogin(t *testing.T) {
 		envVarChecked   bool
 		keychainChecked bool
 		configChecked   bool
-		netrcChecked    bool
 		wantErr         bool
 		envVarReturn    credentialsFuncReturnValues
 		keychainReturn  credentialsFuncReturnValues
 		configReturn    credentialsFuncReturnValues
-		netrcReturn     credentialsFuncReturnValues
 	}{
 		{
 			name:            "CCloud no env var credentials but successful login from keychain",
@@ -339,20 +315,6 @@ func TestPrerun_AutoLogin(t *testing.T) {
 			keychainChecked: true,
 			configChecked:   true,
 		},
-		{
-			name:          "Confluent no env var credentials but successful login from netrc",
-			envVarReturn:  credentialsFuncReturnValues{nil, nil},
-			netrcReturn:   credentialsFuncReturnValues{confluentCreds, nil},
-			envVarChecked: true,
-			netrcChecked:  true,
-		},
-		{
-			name:          "Confluent no env var credentials but successful login from netrc",
-			envVarReturn:  credentialsFuncReturnValues{nil, nil},
-			netrcReturn:   credentialsFuncReturnValues{confluentCreds, nil},
-			envVarChecked: true,
-			netrcChecked:  true,
-		},
 		{
 			name:          "CCloud successful login from env var",
 			isCloud:       true,
@@ -377,21 +339,12 @@ func TestPrerun_AutoLogin(t *testing.T) {
 			keychainChecked: true,
 			configChecked:   true,
 		},
-		{
-			name:          "Confluent env var failed but netrc succeeds",
-			envVarReturn:  credentialsFuncReturnValues{nil, fmt.Errorf("ENV VAR FAILED")},
-			netrcReturn:   credentialsFuncReturnValues{confluentCreds, nil},
-			envVarChecked: true,
-			netrcChecked:  true,
-		},
 		{
 			name:            "CCloud failed non-interactive login",
 			isCloud:         true,
 			envVarReturn:    credentialsFuncReturnValues{nil, fmt.Errorf("ENV VAR FAILED")},
-			netrcReturn:     credentialsFuncReturnValues{nil, fmt.Errorf("NETRC FAILED")},
 			envVarChecked:   true,
 			keychainChecked: true,
-			netrcChecked:    true,
 			configChecked:   true,
 			wantErr:         true,
 		},
@@ -400,7 +353,6 @@ func TestPrerun_AutoLogin(t *testing.T) {
 			envVarReturn:  credentialsFuncReturnValues{nil, fmt.Errorf("ENV VAR FAILED")},
 			configReturn:  credentialsFuncReturnValues{nil, fmt.Errorf("CONFIG FAILED")},
 			envVarChecked: true,
-			netrcChecked:  true,
 			wantErr:       true,
 		},
 	}
@@ -443,11 +395,9 @@ func TestPrerun_AutoLogin(t *testing.T) {
 			}
 
 			var ccloudEnvVarCalled bool
-			var ccloudNetrcCalled bool
 			var ccloudConfigCalled bool
 			var ccloudKeychainCalled bool
 			var confluentEnvVarCalled bool
-			var confluentNetrcCalled bool
 			r.LoginCredentialsManager = &climock.LoginCredentialsManager{
 				GetCloudCredentialsFromEnvVarFunc: func(_ string) func() (*pauth.Credentials, error) {
 					return func() (*pauth.Credentials, error) {
@@ -455,12 +405,6 @@ func TestPrerun_AutoLogin(t *testing.T) {
 						return test.envVarReturn.creds, test.envVarReturn.err
 					}
 				},
-				GetCredentialsFromNetrcFunc: func(_ netrc.NetrcMachineParams) func() (*pauth.Credentials, error) {
-					return func() (*pauth.Credentials, error) {
-						ccloudNetrcCalled = true
-						return test.netrcReturn.creds, test.netrcReturn.err
-					}
-				},
 				GetPrerunCredentialsFromConfigFunc: func(_ *config.Config) func() (*pauth.Credentials, error) {
 					return func() (*pauth.Credentials, error) {
 						ccloudConfigCalled = true
@@ -473,13 +417,7 @@ func TestPrerun_AutoLogin(t *testing.T) {
 						return test.envVarReturn.creds, test.envVarReturn.err
 					}
 				},
-				GetOnPremPrerunCredentialsFromNetrcFunc: func(_ netrc.NetrcMachineParams) func() (*pauth.Credentials, error) {
-					return func() (*pauth.Credentials, error) {
-						confluentNetrcCalled = true
-						return test.netrcReturn.creds, test.netrcReturn.err
-					}
-				},
-				GetCredentialsFromConfigFunc: func(_ *config.Config, _ netrc.NetrcMachineParams) func() (*pauth.Credentials, error) {
+				GetCredentialsFromConfigFunc: func(_ *config.Config, _ config.MachineParams) func() (*pauth.Credentials, error) {
 					return func() (*pauth.Credentials, error) {
 						return nil, nil
 					}
@@ -508,13 +446,11 @@ func TestPrerun_AutoLogin(t *testing.T) {
 
 			if test.isCloud {
 				require.Equal(t, test.envVarChecked, ccloudEnvVarCalled)
-				require.Equal(t, test.netrcChecked, ccloudNetrcCalled)
 				require.Equal(t, test.configChecked, ccloudConfigCalled)
 				require.Equal(t, test.keychainChecked, ccloudKeychainCalled)
 				require.False(t, confluentEnvVarCalled)
 			} else {
 				require.Equal(t, test.envVarChecked, confluentEnvVarCalled)
-				require.Equal(t, test.netrcChecked, confluentNetrcCalled)
 				require.Equal(t, test.keychainChecked, ccloudKeychainCalled)
 				require.False(t, ccloudEnvVarCalled)
 			}
@@ -560,7 +496,6 @@ func TestPrerun_ReLoginToLastOrgUsed(t *testing.T) {
 		},
 	}
 	r.LoginCredentialsManager = &climock.LoginCredentialsManager{
-		GetCredentialsFromNetrcFunc: mockLoginCredentialsManager.GetCredentialsFromNetrcFunc,
 		GetCloudCredentialsFromEnvVarFunc: func(_ string) func() (*pauth.Credentials, error) {
 			return func() (*pauth.Credentials, error) {
 				return ccloudCreds, nil
@@ -571,7 +506,7 @@ func TestPrerun_ReLoginToLastOrgUsed(t *testing.T) {
 				return nil, nil
 			}
 		},
-		GetCredentialsFromConfigFunc: func(_ *config.Config, _ netrc.NetrcMachineParams) func() (*pauth.Credentials, error) {
+		GetCredentialsFromConfigFunc: func(_ *config.Config, _ config.MachineParams) func() (*pauth.Credentials, error) {
 			return func() (*pauth.Credentials, error) {
 				return nil, nil
 			}
@@ -623,7 +558,6 @@ func TestPrerun_AutoLoginNotTriggeredIfLoggedIn(t *testing.T) {
 			cfg.Context().Platform.Server = "https://confluent.cloud"
 
 			var envVarCalled bool
-			var netrcCalled bool
 			mockLoginCredentialsManager := &climock.LoginCredentialsManager{
 				GetCloudCredentialsFromEnvVarFunc: func(_ string) func() (*pauth.Credentials, error) {
 					return func() (*pauth.Credentials, error) {
@@ -631,12 +565,6 @@ func TestPrerun_AutoLoginNotTriggeredIfLoggedIn(t *testing.T) {
 						return nil, nil
 					}
 				},
-				GetCredentialsFromNetrcFunc: func(_ netrc.NetrcMachineParams) func() (*pauth.Credentials, error) {
-					return func() (*pauth.Credentials, error) {
-						netrcCalled = true
-						return nil, nil
-					}
-				},
 				GetCredentialsFromKeychainFunc: func(_ bool, _, _ string) func() (*pauth.Credentials, error) {
 					return func() (*pauth.Credentials, error) {
 						return nil, nil
@@ -663,7 +591,6 @@ func TestPrerun_AutoLoginNotTriggeredIfLoggedIn(t *testing.T) {
 
 			_, err := pcmd.ExecuteCommand(rootCmd.Command)
 			require.NoError(t, err)
-			require.False(t, netrcCalled)
 			require.False(t, envVarCalled)
 		})
 	}
