@@ -231,11 +231,11 @@ func TestConfig_Load(t *testing.T) {
 			file: "test_json/stateful_cloud.json",
 		},
 		{
-			name: "should load disable update checks and disable updates",
+			name: "should load disable update checks",
 			want: &Config{
 				Filename:           "test_json/load_disable_update.json",
-				DisableUpdates:     true,
 				DisableUpdateCheck: true,
+				EnableColor:        true,
 				Platforms:          map[string]*Platform{},
 				Credentials:        map[string]*Credential{},
 				Contexts:           map[string]*Context{},
