@@ -14,7 +14,7 @@ import (
 	"github.com/confluentinc/cli/v3/pkg/utils"
 )
 
-func ValidateAndConfirmDeletionYesNo(cmd *cobra.Command, args []string, checkExistence func(string) bool, resourceType string) error {
+func ValidateAndConfirm(cmd *cobra.Command, args []string, checkExistence func(string) bool, resourceType string) error {
 	if err := resource.ValidatePrefixes(resourceType, args); err != nil {
 		return err
 	}
@@ -23,31 +23,10 @@ func ValidateAndConfirmDeletionYesNo(cmd *cobra.Command, args []string, checkExi
 		return err
 	}
 
-	return ConfirmPromptYesOrNo(cmd, DefaultYesNoDeletePromptString(resourceType, args))
+	return ConfirmPrompt(cmd, DefaultYesNoDeletePromptString(resourceType, args))
 }
 
-func ValidateAndConfirmDeletion(cmd *cobra.Command, args []string, checkExistence func(string) bool, resourceType, name string) error {
-	if err := resource.ValidatePrefixes(resourceType, args); err != nil {
-		return err
-	}
-
-	if err := resource.ValidateArgs(cmd, args, resourceType, checkExistence); err != nil {
-		return err
-	}
-
-	if len(args) > 1 {
-		return ConfirmPromptYesOrNo(cmd, DefaultYesNoDeletePromptString(resourceType, args))
-	}
-
-	promptString := fmt.Sprintf(errors.DeleteResourceConfirmMsg, resourceType, args[0], name)
-	if err := ConfirmDeletionWithString(cmd, promptString, name); err != nil {
-		return err
-	}
-
-	return nil
-}
-
-func ConfirmPromptYesOrNo(cmd *cobra.Command, promptMsg string) error {
+func ConfirmPrompt(cmd *cobra.Command, promptMsg string) error {
 	if force, err := cmd.Flags().GetBool("force"); err != nil {
 		return err
 	} else if force {
@@ -67,29 +46,6 @@ func ConfirmPromptYesOrNo(cmd *cobra.Command, promptMsg string) error {
 	return nil
 }
 
-func ConfirmDeletionWithString(cmd *cobra.Command, promptMsg, stringToType string) error {
-	if force, err := cmd.Flags().GetBool("force"); err != nil {
-		return err
-	} else if force {
-		return nil
-	}
-
-	prompt := form.NewPrompt()
-	f := form.New(form.Field{ID: "confirm", Prompt: promptMsg})
-	if err := f.Prompt(prompt); err != nil {
-		return err
-	}
-
-	if f.Responses["confirm"].(string) == stringToType || f.Responses["confirm"].(string) == fmt.Sprintf(`"%s"`, stringToType) {
-		return nil
-	}
-
-	return errors.NewErrorWithSuggestions(
-		fmt.Sprintf(`input does not match "%s"`, stringToType),
-		"Use the `--force` flag to delete without a confirmation prompt.",
-	)
-}
-
 func DeleteWithoutMessage(args []string, callDeleteEndpoint func(string) error) ([]string, error) {
 	errs := &multierror.Error{ErrorFormat: errors.CustomMultierrorList}
 	var deletedIds []string
@@ -122,7 +78,8 @@ func DefaultYesNoDeletePromptString(resourceType string, idList []string) string
 	if len(idList) == 1 {
 		promptMsg = fmt.Sprintf(`Are you sure you want to delete %s "%s"?`, resourceType, idList[0])
 	} else {
-		promptMsg = fmt.Sprintf("Are you sure you want to delete %ss %s?", resourceType, utils.ArrayToCommaDelimitedString(idList, "and"))
+		plural := resource.Plural(resourceType)
+		promptMsg = fmt.Sprintf("Are you sure you want to delete %s %s?", plural, utils.ArrayToCommaDelimitedString(idList, "and"))
 	}
 
 	return promptMsg
@@ -137,16 +94,7 @@ func ValidateAndConfirmUndeletion(cmd *cobra.Command, args []string, checkExiste
 		return err
 	}
 
-	if len(args) > 1 {
-		return ConfirmPromptYesOrNo(cmd, DefaultYesNoUndeletePromptString(resourceType, args))
-	}
-
-	promptString := fmt.Sprintf(errors.UndeleteResourceConfirmMsg, resourceType, args[0], name)
-	if err := ConfirmDeletionWithString(cmd, promptString, name); err != nil {
-		return err
-	}
-
-	return nil
+	return ConfirmPrompt(cmd, DefaultYesNoUndeletePromptString(resourceType, args))
 }
 
 func UndeleteWithoutMessage(args []string, callUndeleteEndpoint func(string) error) ([]string, error) {
