@@ -8,7 +8,6 @@ import (
 	"net/http/httputil"
 
 	"github.com/confluentinc/cli/v3/pkg/cpstructs"
-	"github.com/confluentinc/cli/v3/pkg/errors"
 	"github.com/confluentinc/cli/v3/pkg/log"
 )
 
@@ -16,7 +15,7 @@ const clientNotInitializedErrorMsg = "Hub client not initialized"
 
 func (c *Client) GetRemoteManifest(owner, name, version string) (*cpstructs.Manifest, error) {
 	if c == nil {
-		return nil, errors.New(clientNotInitializedErrorMsg)
+		return nil, fmt.Errorf(clientNotInitializedErrorMsg)
 	}
 
 	manifestUrl := fmt.Sprintf("%s/api/plugins/%s/%s", c.URL, owner, name)
@@ -61,9 +60,9 @@ func (c *Client) GetRemoteManifest(owner, name, version string) (*cpstructs.Mani
 		response := make(map[string]interface{})
 		_ = json.Unmarshal(body, &response)
 		if errorMessage, ok := response["message"]; ok {
-			return nil, errors.Errorf("failed to read manifest file from Confluent Hub: %s", errorMessage)
+			return nil, fmt.Errorf("failed to read manifest file from Confluent Hub: %s", errorMessage)
 		}
-		return nil, errors.Errorf("failed to read manifest file from Confluent Hub")
+		return nil, fmt.Errorf("failed to read manifest file from Confluent Hub")
 	}
 
 	pluginManifest := new(cpstructs.Manifest)
@@ -76,7 +75,7 @@ func (c *Client) GetRemoteManifest(owner, name, version string) (*cpstructs.Mani
 
 func (c *Client) GetRemoteArchive(pluginManifest *cpstructs.Manifest) ([]byte, error) {
 	if c == nil {
-		return nil, errors.New(clientNotInitializedErrorMsg)
+		return nil, fmt.Errorf(clientNotInitializedErrorMsg)
 	}
 
 	req, err := http.NewRequest(http.MethodGet, pluginManifest.Archive.Url, nil)
@@ -100,7 +99,7 @@ func (c *Client) GetRemoteArchive(pluginManifest *cpstructs.Manifest) ([]byte, e
 	defer r.Body.Close()
 
 	if r.StatusCode != http.StatusOK {
-		return nil, errors.New("failed to retrieve archive from Confuent Hub")
+		return nil, fmt.Errorf("failed to retrieve archive from Confuent Hub")
 	}
 
 	return io.ReadAll(r.Body)
