@@ -17,6 +17,7 @@ import (
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 
+	"github.com/confluentinc/cli/v3/pkg/config"
 	pio "github.com/confluentinc/cli/v3/pkg/io"
 	"github.com/confluentinc/cli/v3/pkg/mock"
 	updateMock "github.com/confluentinc/cli/v3/pkg/update/mock"
@@ -24,6 +25,8 @@ import (
 )
 
 func TestNewClient(t *testing.T) {
+	cfg := config.New()
+
 	tests := []struct {
 		name   string
 		params *ClientParams
@@ -36,6 +39,7 @@ func TestNewClient(t *testing.T) {
 				ClientParams: &ClientParams{CheckInterval: 24 * time.Hour, OS: runtime.GOOS},
 				clock:        clockwork.NewRealClock(),
 				fs:           &pio.RealFileSystem{},
+				cfg:          cfg,
 			},
 		},
 		{
@@ -53,12 +57,13 @@ func TestNewClient(t *testing.T) {
 				},
 				clock: clockwork.NewRealClock(),
 				fs:    &pio.RealFileSystem{},
+				cfg:   cfg,
 			},
 		},
 	}
 	for _, test := range tests {
 		t.Run(test.name, func(t *testing.T) {
-			if got := NewClient(test.params); !reflect.DeepEqual(got, test.want) {
+			if got := NewClient(cfg, test.params); !reflect.DeepEqual(got, test.want) {
 				t.Errorf("NewClient() = %#v, want %#v", got, test.want)
 			}
 		})
@@ -66,9 +71,9 @@ func TestNewClient(t *testing.T) {
 }
 
 func TestCheckForUpdates(t *testing.T) {
-	tmpCheckFile1, err := os.CreateTemp("", "cli-test1-")
-	require.NoError(t, err)
-	defer os.Remove(tmpCheckFile1.Name())
+	cfgCurrentTime := config.New()
+	currentTime := time.Now()
+	cfgCurrentTime.LastUpdateCheckAt = &currentTime
 
 	type args struct {
 		name           string
@@ -85,7 +90,7 @@ func TestCheckForUpdates(t *testing.T) {
 	}{
 		{
 			name: "should err if currentVersion isn't semver",
-			client: NewClient(&ClientParams{
+			client: NewClient(config.New(), &ClientParams{
 				Repository: &updateMock.Repository{},
 			}),
 			args: args{
@@ -96,7 +101,7 @@ func TestCheckForUpdates(t *testing.T) {
 		},
 		{
 			name: "should err if can't get versions",
-			client: NewClient(&ClientParams{
+			client: NewClient(config.New(), &ClientParams{
 				Repository: &updateMock.Repository{
 					GetLatestMajorAndMinorVersionFunc: func(name string, current *version.Version) (*version.Version, *version.Version, error) {
 						return nil, nil, fmt.Errorf("zap")
@@ -111,7 +116,7 @@ func TestCheckForUpdates(t *testing.T) {
 		},
 		{
 			name: "should return the new version",
-			client: NewClient(&ClientParams{
+			client: NewClient(config.New(), &ClientParams{
 				Repository: &updateMock.Repository{
 					GetLatestMajorAndMinorVersionFunc: func(name string, current *version.Version) (*version.Version, *version.Version, error) {
 						v3, _ := version.NewSemver("v3")
@@ -127,14 +132,13 @@ func TestCheckForUpdates(t *testing.T) {
 		},
 		{
 			name: "should not check for the new version if has checked recently",
-			client: NewClient(&ClientParams{
+			client: NewClient(cfgCurrentTime, &ClientParams{
 				Repository: &updateMock.Repository{
 					GetLatestMajorAndMinorVersionFunc: func(name string, current *version.Version) (*version.Version, *version.Version, error) {
 						v3, _ := version.NewSemver("v3")
 						return v3, v3, nil
 					},
 				},
-				CheckFile: tmpCheckFile1.Name(),
 			}),
 			args: args{
 				name:           "my-cli",
@@ -143,15 +147,14 @@ func TestCheckForUpdates(t *testing.T) {
 		},
 		{
 			name: "should not check again if checked recently",
-			client: NewClient(&ClientParams{
+			// cfgCurrentTime.LastUpdateCheckAt was set at the start of the test and is current, so should skip check
+			client: NewClient(cfgCurrentTime, &ClientParams{
 				Repository: &updateMock.Repository{
 					GetLatestMajorAndMinorVersionFunc: func(name string, current *version.Version) (*version.Version, *version.Version, error) {
 						require.Fail(t, "Shouldn't be called")
 						return nil, nil, fmt.Errorf("whoops")
 					},
 				},
-				// This check file was created by the TmpFile process, modtime is current, so should skip check
-				CheckFile: tmpCheckFile1.Name(),
 			}),
 			args: args{
 				name:           "my-cli",
@@ -160,15 +163,14 @@ func TestCheckForUpdates(t *testing.T) {
 		},
 		{
 			name: "should respect forceCheck even if you checked recently",
-			client: NewClient(&ClientParams{
+			// cfgCurrentTime.LastUpdateCheckAt was set at the start of the test and is current, so should skip check
+			client: NewClient(cfgCurrentTime, &ClientParams{
 				Repository: &updateMock.Repository{
 					GetLatestMajorAndMinorVersionFunc: func(name string, current *version.Version) (*version.Version, *version.Version, error) {
 						v3, _ := version.NewSemver("v3")
 						return v3, current, nil
 					},
 				},
-				// This check file was created by the TmpFile process, modtime is current, so should skip check
-				CheckFile: tmpCheckFile1.Name(),
 			}),
 			args: args{
 				name:           "my-cli",
@@ -177,45 +179,9 @@ func TestCheckForUpdates(t *testing.T) {
 			},
 			wantMajor: "v3",
 		},
-		{
-			name: "should err if you can't create the CheckFile",
-			client: NewClient(&ClientParams{
-				Repository: &updateMock.Repository{
-					GetLatestMajorAndMinorVersionFunc: func(name string, current *version.Version) (*version.Version, *version.Version, error) {
-						v2, _ := version.NewSemver("v2")
-						return v2, v2, nil
-					},
-				},
-				// This file doesn't exist but you won't have permission to create it
-				CheckFile: "/sbin/cant-write-here",
-			}),
-			args: args{
-				name:           "my-cli",
-				currentVersion: "v1.2.3",
-			},
-			wantErr: true,
-		},
-		{
-			name: "should err if you can't touch the CheckFile",
-			client: NewClient(&ClientParams{
-				Repository: &updateMock.Repository{
-					GetLatestMajorAndMinorVersionFunc: func(name string, current *version.Version) (*version.Version, *version.Version, error) {
-						v2, _ := version.NewSemver("v2")
-						return v2, v2, nil
-					},
-				},
-				// This file doesn't exist but you won't have permission to touch it
-				CheckFile: "/sbin/ping",
-			}),
-			args: args{
-				name:           "my-cli",
-				currentVersion: "v1.2.3",
-			},
-			wantErr: true,
-		},
 		{
 			name: "should not check if disabled",
-			client: NewClient(&ClientParams{
+			client: NewClient(config.New(), &ClientParams{
 				Repository: &updateMock.Repository{
 					GetLatestMajorAndMinorVersionFunc: func(name string, current *version.Version) (*version.Version, *version.Version, error) {
 						require.Fail(t, "Shouldn't be called")
@@ -231,7 +197,7 @@ func TestCheckForUpdates(t *testing.T) {
 		},
 		{
 			name: "checks - error",
-			client: NewClient(&ClientParams{
+			client: NewClient(config.New(), &ClientParams{
 				Repository: &updateMock.Repository{
 					GetLatestMajorAndMinorVersionFunc: func(name string, current *version.Version) (*version.Version, *version.Version, error) {
 						return nil, nil, fmt.Errorf("whoops")
@@ -246,7 +212,7 @@ func TestCheckForUpdates(t *testing.T) {
 		},
 		{
 			name: "checks - success - update",
-			client: NewClient(&ClientParams{
+			client: NewClient(config.New(), &ClientParams{
 				Repository: &updateMock.Repository{
 					GetLatestMajorAndMinorVersionFunc: func(name string, current *version.Version) (*version.Version, *version.Version, error) {
 						v, _ := version.NewVersion("v1.2.4")
@@ -262,7 +228,7 @@ func TestCheckForUpdates(t *testing.T) {
 		},
 		{
 			name: "checks - success - same version",
-			client: NewClient(&ClientParams{
+			client: NewClient(config.New(), &ClientParams{
 				Repository: &updateMock.Repository{
 					GetLatestMajorAndMinorVersionFunc: func(name string, current *version.Version) (*version.Version, *version.Version, error) {
 						v, _ := version.NewVersion("v1.2.4")
@@ -277,7 +243,7 @@ func TestCheckForUpdates(t *testing.T) {
 		},
 		{
 			name: "checks - success - hyphen no update",
-			client: NewClient(&ClientParams{
+			client: NewClient(config.New(), &ClientParams{
 				Repository: &updateMock.Repository{
 					GetLatestMajorAndMinorVersionFunc: func(name string, current *version.Version) (*version.Version, *version.Version, error) {
 						v, _ := version.NewVersion("v0.238.0")
@@ -292,7 +258,7 @@ func TestCheckForUpdates(t *testing.T) {
 		},
 		{
 			name: "checks - success - hyphen same version",
-			client: NewClient(&ClientParams{
+			client: NewClient(config.New(), &ClientParams{
 				Repository: &updateMock.Repository{
 					GetLatestMajorAndMinorVersionFunc: func(name string, current *version.Version) (*version.Version, *version.Version, error) {
 						v, _ := version.NewVersion("v0.238.0-7-g5060ef4")
@@ -307,7 +273,7 @@ func TestCheckForUpdates(t *testing.T) {
 		},
 		{
 			name: "checks - success - hyphen update",
-			client: NewClient(&ClientParams{
+			client: NewClient(config.New(), &ClientParams{
 				Repository: &updateMock.Repository{
 					GetLatestMajorAndMinorVersionFunc: func(name string, current *version.Version) (*version.Version, *version.Version, error) {
 						v, _ := version.NewVersion("v0.238.0-7-g5060ef4")
@@ -323,7 +289,7 @@ func TestCheckForUpdates(t *testing.T) {
 		},
 		{
 			name: "different major and minor versions",
-			client: NewClient(&ClientParams{
+			client: NewClient(config.New(), &ClientParams{
 				Repository: &updateMock.Repository{
 					GetLatestMajorAndMinorVersionFunc: func(_ string, current *version.Version) (*version.Version, *version.Version, error) {
 						v0, _ := version.NewVersion("v0.1.0")
@@ -338,7 +304,7 @@ func TestCheckForUpdates(t *testing.T) {
 		},
 		{
 			name: "no latest major or minor versions",
-			client: NewClient(&ClientParams{
+			client: NewClient(config.New(), &ClientParams{
 				Repository: &updateMock.Repository{
 					GetLatestMajorAndMinorVersionFunc: func(_ string, current *version.Version) (*version.Version, *version.Version, error) {
 						v0, _ := version.NewVersion("v0.0.0")
@@ -371,11 +337,6 @@ func TestCheckForUpdates(t *testing.T) {
 func TestCheckForUpdates_BehaviorOverTime(t *testing.T) {
 	req := require.New(t)
 
-	tmpDir, err := os.MkdirTemp("", "cli-test3-")
-	req.NoError(err)
-	defer os.RemoveAll(tmpDir)
-	checkFile := filepath.FromSlash(fmt.Sprintf("%s/new-check-file", tmpDir))
-
 	repo := &updateMock.Repository{
 		GetLatestMajorAndMinorVersionFunc: func(name string, current *version.Version) (*version.Version, *version.Version, error) {
 			v3, _ := version.NewSemver("v3")
@@ -383,9 +344,8 @@ func TestCheckForUpdates_BehaviorOverTime(t *testing.T) {
 		},
 	}
 	clock := clockwork.NewFakeClockAt(time.Now())
-	client := NewClient(&ClientParams{
+	client := NewClient(config.New(), &ClientParams{
 		Repository: repo,
-		CheckFile:  checkFile,
 	})
 	client.clock = clock
 
@@ -414,46 +374,6 @@ func TestCheckForUpdates_BehaviorOverTime(t *testing.T) {
 	req.Equal("v3", latestMajorVersion)
 	req.Equal("v3", latestMinorVersion)
 	req.True(repo.GetLatestMajorAndMinorVersionCalled())
-
-	// Shouldn't check anymore for 24 hours
-	for i := 0; i < 3; i++ {
-		clock.Advance(8*time.Hour + -1*time.Second)
-		repo.Reset()
-
-		_, _, _ = client.CheckForUpdates("my-cli", "v1.2.3", false)
-		req.False(repo.GetLatestMajorAndMinorVersionCalled())
-	}
-
-	// Finally we should check once more
-	clock.Advance(3 * time.Second)
-	repo.Reset()
-	_, _, _ = client.CheckForUpdates("my-cli", "v1.2.3", false)
-	req.True(repo.GetLatestMajorAndMinorVersionCalled())
-}
-
-func TestCheckForUpdates_NoCheckFileGiven(t *testing.T) {
-	req := require.New(t)
-
-	repo := &updateMock.Repository{
-		GetLatestMajorAndMinorVersionFunc: func(name string, current *version.Version) (*version.Version, *version.Version, error) {
-			v3, _ := version.NewSemver("v3")
-			return v3, v3, nil
-		},
-	}
-	client := NewClient(&ClientParams{
-		Repository: repo,
-	})
-	client.clock = clockwork.NewFakeClockAt(time.Now())
-
-	// Should check for updates every time if no CheckFile given to serve as the "last check" cache
-	for i := 0; i < 3; i++ {
-		latestMajorVersion, latestMinorVersion, err := client.CheckForUpdates("my-cli", "v1.2.3", false)
-		req.NoError(err)
-		req.Equal("v3", latestMajorVersion)
-		req.Equal("v3", latestMinorVersion)
-		req.True(repo.GetLatestMajorAndMinorVersionCalled())
-		repo.Reset()
-	}
 }
 
 func TestDownloadChecksum(t *testing.T) {
@@ -516,7 +436,7 @@ func TestGetLatestReleaseNotes(t *testing.T) {
 	}{
 		{
 			name: "success",
-			client: NewClient(&ClientParams{
+			client: NewClient(config.New(), &ClientParams{
 				Repository: &updateMock.Repository{
 					GetLatestReleaseNotesVersionsFunc: func(_, _ string) (version.Collection, error) {
 						v, _ := version.NewSemver(releaseNotesVersion)
@@ -533,7 +453,7 @@ func TestGetLatestReleaseNotes(t *testing.T) {
 		},
 		{
 			name: "error getting release notes version",
-			client: NewClient(&ClientParams{
+			client: NewClient(config.New(), &ClientParams{
 				Repository: &updateMock.Repository{
 					GetLatestReleaseNotesVersionsFunc: func(_, _ string) (version.Collection, error) {
 						return nil, fmt.Errorf("whoops")
@@ -547,7 +467,7 @@ func TestGetLatestReleaseNotes(t *testing.T) {
 		},
 		{
 			name: "error downloading release notes",
-			client: NewClient(&ClientParams{
+			client: NewClient(config.New(), &ClientParams{
 				Repository: &updateMock.Repository{
 					GetLatestReleaseNotesVersionsFunc: func(_, _ string) (version.Collection, error) {
 						v1, _ := version.NewSemver("v1")
@@ -709,7 +629,7 @@ func TestPromptToDownload(t *testing.T) {
 	}
 
 	makeClient := func(fs pio.FileSystem) *client {
-		client := NewClient(&ClientParams{
+		client := NewClient(config.New(), &ClientParams{
 			Repository: &updateMock.Repository{},
 		})
 		client.clock = clock
