@@ -37,7 +37,7 @@ func (s *CLITestSuite) TestEnvironmentDescribe() {
 func (s *CLITestSuite) TestEnvironmentDelete() {
 	tests := []CLITest{
 		{args: "environment delete env-595 --force", fixture: "environment/delete/success.golden"},
-		{args: "environment delete env-595", input: "default\n", fixture: "environment/delete/success-prompt.golden"},
+		{args: "environment delete env-595", input: "y\n", fixture: "environment/delete/success-prompt.golden"},
 		{args: "environment delete env-dne", fixture: "environment/delete/fail.golden", exitCode: 1},
 		{args: "environment delete env-srUpdate env-dne", fixture: "environment/delete/multiple-fail.golden", exitCode: 1},
 		{args: "environment delete env-srUpdate env-595", input: "n\n", fixture: "environment/delete/multiple-refuse.golden"},
